Page 112 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 112

Home

    Amazing as it is, and for whatever reason, these
    outrages have occurred without a cry of protest upon the
    part of many of the world's most well known religious
    leaders. Like the Priest and the Levite (in the story of the
    good Samaritan) who ignored the plight of the man who
    was beaten and robbed by thieves, they too have "passed
    by on the other side."

    It is not well known that one of the first countries to

    become a victim of the war on religion during the 20th
    century, and the first country in this hemisphere to be
    betrayed into Communism, was Mexico. To realize the
    full import of this, it is necessary to review some of
    Mexico's history leading up to these events.

    Before the 19th century, primarily through the efforts
    of the Catholic Church, the inhabitants of Mexico were
    elevated to a settled Christian people, unified by a
    common faith, and possessing the arts and industries of
    a self-sustaining civilization. This was no less than a
    miracle of transformation from hostile nomadic tribes,

    speaking different languages, and ruled by the Aztecs
    who annually sacrificed tens of thousands of human
    beings upon their polytheistic altars.

    The University of Mexico was established in 1553,
    almost a hundred years before Harvard. From the
    sixteenth to eighteenth century, it produced a series of
    native poets, dramatists, historians, jurists, scientists, and
    journalists of such excellence that North America had
    little comparable. Mexico had the first printing press in
    the new world. It was engaged in printing catechisms,

    107

    Babylon's War Against God